@@ -1,4 +1,36 @@
-#!/usr/bin/python3
+"""Discoverable filesystems
+
+Extend `FileSystem` with support for dynamic data. E.g. data from a REST resource.
+
+Usage
+-----
+```py
+fs = Discoverable({'repository': User},
+                  get_value_method=observe)
+```
+
+where
+```py
+@dataclass
+class User:
+    # A REST resource of the endpoints `/users` and `/users/{id}`
+    email: str
+    role: str
+
+    @staticmethod
+    def get_value(path: Path):
+        # Retrieve external data and instantiate this class.
+
+    @staticmethod
+    def get_all(path: Path):
+        # Return resource identifiers.
+
+    @staticmethod
+    def refresh() -> bool:
+        # Return True to indicate that a resource should be refreshed.
+
+```
+"""
 from dataclasses import _MISSING_TYPE
 from pickle import dumps, loads
 from typing import Callable,  Union
@@ -9,14 +41,14 @@ from mash.filesystem.filesystem import FileSystem
 from mash.filesystem.view import Data, Path, Key, View
 
 
-Method = Union[Callable[[FileSystem, Key, Data, View], Data], str]
+ObserveMethod = Union[Callable[[FileSystem, Key, Data, View], Data], str]
 
 default_snapshot_filename = '.snapshot.pickle'
 
 
 class Discoverable(FileSystem):
     def __init__(self, *args,
-                 get_value_method: Method = None,
+                 get_value_method: ObserveMethod = None,
                  **kwds):
         self.get_value_method = get_value_method
         self.initial_values = {}
@@ -109,7 +141,7 @@ class Discoverable(FileSystem):
         if len(self.full_path) <= 1:
             return data
 
-        p = '/'.join(path)
+        p = '/'.join(str(item) for item in path)
         if p in self.initial_values:
             cls = self.initial_values[p]
             if has_method(cls, 'show'):
@@ -150,7 +182,7 @@ def observe(repository: FileSystem, k: Key, initial_value=None, cwd: View = None
         cls = data
 
     if isinstance(cls, type):
-        return discover_using_cls(cls, k, container_cls, repository.full_path)
+        return discover_using_cls(cls, k, container_cls, cwd.path)
 
     initial_values_key = '/'.join([str(v) for v in cwd.path + [k]])
 
