@@ -44,34 +44,22 @@ class ShellWithFileSystem:
         # convert methods to functions
         cd = partial_simple(self.repository.cd)
         ll = partial_simple(self.repository.ll)
-        get = partial_simple(self.get)
-        set = partial_simple(self.set)
-        new = partial_simple(self.new)
-        tree = partial_simple(self.repository.tree)
-        pwd = partial_simple(self.pwd)
-        home = partial_simple(self.init_home)
-        cp = partial_simple(self.repository.cp)
-        mv = partial_simple(self.repository.mv)
-        rm = partial_simple(self.repository.rm)
-        # show = partial_simple(self.show)
-        show = partial_simple(self.repository.show)
-        reset = partial_simple(self.repository.reset)
 
         set_functions({'cd': cd,
                        'use': cd,
                        'l': ll,
                        'list': ll,
-                       'get': get,
-                       'set': set,
-                       'new': new,
-                       'tree': tree,
-                       'pwd': pwd,
-                       'home': home,
-                       'cp': cp,
-                       'mv': mv,
-                       'rm': rm,
-                       'show': show,
-                       'reset': reset,
+                       'get': partial_simple(self.get),
+                       'set': partial_simple(self.set),
+                       'new': partial_simple(self.new),
+                       'tree': partial_simple(self.repository.tree),
+                       'pwd': partial_simple(self.pwd),
+                       'home': partial_simple(self.init_home),
+                       'cp': partial_simple(self.repository.cp),
+                       'mv': partial_simple(self.repository.mv),
+                       'rm': partial_simple(self.repository.rm),
+                       'show': partial_simple(self.repository.show),
+                       'reset': partial_simple(self.repository.reset),
                        }, cls)
 
     def cd(self, *path: str):
@@ -156,7 +144,7 @@ class ShellWithFileSystem:
         if not hasattr(self, 'repository'):
             return
 
-        semantic_path = self.repository.semantic_path
+        semantic_path = list(self.repository.semantic_path)
 
         if path_delimiter == Option.root.value:
             # avoid double '//' in path
@@ -174,6 +162,7 @@ class ShellWithFileSystem:
         """Filter the result of `ls` to match `text`.
         """
         candidates = self.repository.ls()
+        candidates = [str(c) for c in candidates]
         results = list(find_fuzzy_matches(text, candidates))
 
         if len(results) > 1:
@@ -185,8 +174,8 @@ class ShellWithFileSystem:
     def default_method(self, dirname: str):
         candidates = self.complete_cd(dirname, None, None, None)
         if candidates:
-            error = hamming(dirname, candidates[0])
-            if error < 0.9:
+            error = hamming(dirname, str(candidates[0]))
+            if error < 0.8:
                 self.repository.cd(candidates[0])
                 return
 
