@@ -96,6 +96,7 @@ def infer_dependencies(known_deps: AdjacencyList, key: str):
 
 
 def crop(s: str, n=100, suffix='..') -> str:
+    s = str(s)
     margin = len(suffix)
     if len(s) <= n + margin:
         return s
@@ -372,7 +373,7 @@ def find_prefix_matches(element: str, elements: MappingView[str]):
         yield match
 
     if i == -1:
-        preview = ', '.join(take(elements, 3))
+        preview = ', '.join((str(e) for e in take(elements, 3)))
         raise ValueError(
             f'{element} is not a prefix of any of the given items [{preview}, ..]')
 
@@ -388,7 +389,7 @@ def list_prefix_matches(element: str, elements: List[str]):
             if other in prev_matches:
                 continue
 
-            if other.startswith(prefix):
+            if str(other).startswith(prefix):
                 prev_matches |= {other}
                 yield other
 
